<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    public function up(): void
    {
        Schema::table('system_settings', function (Blueprint $table) {
            $table->decimal('account_commission_pct', 5, 2)->default(5.00)->after('exchange_rate_usd_bob');
            $table->decimal('sales_commission_pct', 5, 2)->default(25.00)->after('account_commission_pct');
        });
    }

    public function down(): void
    {
        Schema::table('system_settings', function (Blueprint $table) {
            $table->dropColumn(['account_commission_pct', 'sales_commission_pct']);
        });
    }
};
