<?php

namespace Database\Seeders;

use App\Models\SystemSetting;
use Illuminate\Database\Seeder;

class SystemSettingSeeder extends Seeder
{
    public function run(): void
    {
        SystemSetting::updateOrCreate(
            ['id' => 1],
            [
                'base_currency'         => 'USD',
                'exchange_rate_usd_bob' => 6.9600,
            ]
        );
    }
}
