<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    public function up(): void
    {
        Schema::table('system_settings', function (Blueprint $table) {
            $table->string('claude_api_key')->nullable()->after('exchange_rate_usd_bob');
            $table->string('claude_model')->default('claude-haiku-4-5-20251001')->after('claude_api_key');
        });
    }

    public function down(): void
    {
        Schema::table('system_settings', function (Blueprint $table) {
            $table->dropColumn(['claude_api_key', 'claude_model']);
        });
    }
};
