<?php

use Illuminate\Database\Migrations\Migration;

return new class extends Migration
{
    public function up(): void
    {
        DB::statement("ALTER TABLE users MODIFY COLUMN role ENUM('admin_sistema','contador_admin','gestor_cuenta','vendedor') NOT NULL DEFAULT 'gestor_cuenta'");
    }

    public function down(): void
    {
        DB::statement("ALTER TABLE users MODIFY COLUMN role ENUM('admin_sistema','contador_admin','gestor_cuenta') NOT NULL DEFAULT 'gestor_cuenta'");
    }
};
